Module line

Module line 

Structs

Args
Read one line from standard input and write it to standard output.

Constants

MAN

Functions

line
Read one line from reader and write it to writer, followed by a newline.
run