rev

Function rev 

pub fn rev(
    reader: impl BufRead,
    writer: &mut impl Write,
    zero: bool,
) -> Result<()>
Reverse each line from reader and write to writer.

If zero is true, lines are delimited by ā€˜\0’ instead of ā€˜\n’.